<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:template match="/">
  <html><body>
    <xsl:apply-templates select="framscontext"/>
  </body></html>
</xsl:template>

<xsl:template match="framscontext">
  <h1>Framscript Context Configuration</h1>
<i>Note:
  <xsl:choose><xsl:when test="count(document('framscript.xml')/framscript)=0">
	This formatting sheet would also use <a href="framscript.xml">framscript.xml</a> to show object names if that file was available</xsl:when>
<xsl:otherwise>This formatting sheet also includes object names extracted from <a href="framscript.xml">framscript.xml</a></xsl:otherwise>
	</xsl:choose>
</i>

  <table border="1">
  <th>File types</th><th>Contents</th><th>Examples</th>
  <xsl:apply-templates select="file"/>
  </table>
</xsl:template>

<xsl:template match="file">
  <tr valign="top">
   <td><b><xsl:value-of select="@label"/></b><br/><xsl:value-of select="@pattern"/></td>
   <td>
	<xsl:if test="count(code)!=0">
	<p title="Defined by &lt;objects&gt;">
	Objects defined in the following contexts can be stored directly in the file: (using the standard framsticks format)<ul><xsl:apply-templates select="objects"/></ul>
	</p>
	<xsl:apply-templates select="code"/>
	</xsl:if>
	<xsl:if test="count(script)!=0">
	<p title="Defined by &lt;script&gt;">
	Contains the script (plain text format) accessing objects defined in the following contexts:<ul><xsl:apply-templates select="script"/></ul>
	</p>
	</xsl:if>
	<xsl:if test="count(properties)!=0">
	<p title="Defined by &lt;properties&gt;">
	Special objects properties are created according to property definitions in the file:<ul><xsl:apply-templates select="properties"/></ul>
	</p>
	</xsl:if>
	</td>
   <td><i>sample <xsl:value-of select="@pattern"/> file</i><br/>
	<pre style="background:#eeeeee;">
<xsl:if test="count(code)!=0">
# object defined in "<xsl:value-of select="objects[1]/@context"/>"
object:
field_1:...
field_2:...
</xsl:if>

<xsl:if test="count(code)!=0">
# sample object that contains the script:
<xsl:value-of select="code[1]/@object"/>:
field_1:...
field_2:...
<xsl:value-of select="code[1]/@member"/>:~
function fun()
{
// using some objects from "<xsl:value-of select="code[1]/context[1]/@name"/>"
}
~
</xsl:if>
<xsl:if test="count(properties)!=0">
# this property will be visible as "<xsl:value-of select="properties[1]/@to"/>.field"
<xsl:value-of select="properties[1]/@from"/>:
id:field
name:My property
...
</xsl:if>

<xsl:if test="count(script)!=0">
// script directly in the file
function fun()
{
// using some objects from <xsl:value-of select="script[1]/@context"/>
}
</xsl:if>

</pre>
   </td>
  </tr>
</xsl:template>

<xsl:template match="objects">
  <li><b><xsl:value-of select="@context"/></b>
	<xsl:variable name="context" select="@context"/>
      	<xsl:call-template name="extobjects"><xsl:with-param name="objs" select="document('framscript.xml')/framscript/type[@context=$context]"/></xsl:call-template>
  </li>
</xsl:template>

<xsl:template match="script">
  <li><b><xsl:value-of select="@context"/></b>
	<xsl:variable name="context" select="@context"/>
      	<xsl:call-template name="extobjects"><xsl:with-param name="objs" select="document('framscript.xml')/framscript/type[@context=$context]"/></xsl:call-template>
  </li>
</xsl:template>

<xsl:template name="extobjects">
  <xsl:param name="objs"/>
  <xsl:if test="count($objs)!=0">
  (
  <xsl:for-each select="$objs">
	<xsl:value-of select="@name"/>,
  </xsl:for-each>
  )
  </xsl:if>
</xsl:template>

<xsl:template match="context">
  <li><b><xsl:value-of select="@name"/></b>
	<xsl:variable name="context" select="@name"/>
      	<xsl:call-template name="extobjects"><xsl:with-param name="objs" select="document('framscript.xml')/framscript/type[@context=$context]"/></xsl:call-template>
  </li>
</xsl:template>

<xsl:template match="code">
  <p title="Defined by &lt;code&gt;">
  "<xsl:value-of select="@member"/>:" field of "<xsl:value-of select="@object"/>:" contains a script that can access objects defined in the following contexts:<ul><xsl:apply-templates select="context"/></ul>
  </p>
</xsl:template>

<xsl:template match="properties">
  <li>
  <b><xsl:value-of select="@to"/></b> is defined by "<xsl:value-of select="@from"/>" objects
  </li>
</xsl:template>

</xsl:stylesheet>
